/*
 * Patch PRONEWS.DLL to fix Y2K problems.
 * Selects the correct patch file for the DLL.
 *
 * Bob Eager (rde@tavi.co.uk) 16th January 2000
 *
 */

dllname = 'PRONEWS.DLL'
patchlevel = '02'

nversions = 4

check.1 = '0b812c 889424d8010000'
dated.1 = '8th May 1998'
descr.1 = 'the version now available in the Hobbes archive'
patch.1 = 'PNY2KM08.PAT'

check.2 = '0b813c 889424d8010000'
dated.2 = '10th May 1998'
descr.2 = 'a version which was downloadable from the Panacea site'
patch.2 = 'PNY2KM10.PAT'

check.3 = '0b7f3c 889424d8010000'
dated.3 = '6th May 1998'
descr.3 = 'a version which was downloadable from the Panacea site'
patch.3 = 'PNY2KM06.PAT'

check.4 = '0d467c 8d85fafdffff83ec08'
dated.4 = '4th June 1998'
descr.4 = 'a closed beta version, known as build ia119'
patch.4 = 'PNY2KJ04.PAT'

say 'This procedure attempts to patch the file' dllname 'using the'
say 'correct patch file. It will apply the level' patchlevel 'patch.'
say ''

dllfile = stream(dllname, 'c', 'open read')
if dllfile \= 'READY:' then do
   say '+++ Cannot find the file' dllname
   exit 1
end

version = -1
do i = 1 to nversions
   offset = x2d(word(check.i,1)) + 1
   cksize = length(word(check.i,2))/2   /* Number of bytes to check */
   temp = charin(dllname, offset, cksize)
   test = ''
   do j = 1 to cksize
      test = test || c2x(substr(temp,j,1))
   end
   if test = translate(word(check.i,2)) then do
      version = i
      leave
   end
end

call stream dllname,'c','close'

if version = -1 then do
   say '+++ This version of the file' dllname 'is not recognised.'
   say 'Please contact <rde@tavi.co.uk>, giving the size and date of the'
   say dllname 'file which you have. Please DO NOT email or otherwise send'
   say 'the file unless requested to do so.'
   say ''
   say '(You can get the original date of' dllname 'by unzipping'
   say 'the distribution file, then unzipping INSTALL.ZIP, then looking'
   say 'at the date on' dllname 'using the DIR command)'
   exit 1
end

say 'You appear to have the version of' dllname 'originally dated'
say 'the' dated.version || '.'
say 'This is' descr.version || '.'

patchfile = patch.version

backupdll = substr(dllname, 1, lastpos('.', dllname) -1) || '.BAK'
say ''
say 'Backing up' dllname 'to' backupdll || '...'
'@copy' dllname backupdll

say 'Using patch file' patchfile || '...'
'@patch' patchfile '/A'

exit
